@@ -3,7 +3,7 @@ import importlib
 
 
 def _fresh_import_dirs(monkeypatch):
-    for mod in ["lab.dirs", "lab.dirs_workspace"]:
+    for mod in ["lab.dirs"]:
         if mod in importlib.sys.modules:
             importlib.sys.modules.pop(mod)
     from lab import dirs  # noqa: F401
@@ -22,12 +22,12 @@ def test_dirs_structure_created(monkeypatch, tmp_path):
     dirs = _fresh_import_dirs(monkeypatch)
 
     # Key directories exist
-    assert os.path.isdir(dirs.EXPERIMENTS_DIR)
-    assert os.path.isdir(dirs.JOBS_DIR)
-    assert os.path.isdir(dirs.MODELS_DIR)
-    assert os.path.isdir(dirs.DATASETS_DIR)
-    assert os.path.isdir(dirs.TEMP_DIR)
-    assert os.path.isdir(dirs.PROMPT_TEMPLATES_DIR)
-    assert os.path.isdir(dirs.TOOLS_DIR)
-    assert os.path.isdir(dirs.BATCHED_PROMPTS_DIR)
-    assert os.path.isdir(dirs.GALLERIES_CACHE_DIR)
+    assert os.path.isdir(dirs.get_experiments_dir())
+    assert os.path.isdir(dirs.get_jobs_dir())
+    assert os.path.isdir(dirs.get_models_dir())
+    assert os.path.isdir(dirs.get_datasets_dir())
+    assert os.path.isdir(dirs.get_temp_dir())
+    assert os.path.isdir(dirs.get_prompt_templates_dir())
+    assert os.path.isdir(dirs.get_tools_dir())
+    assert os.path.isdir(dirs.get_batched_prompts_dir())
+    assert os.path.isdir(dirs.get_galleries_cache_dir())
